@@ -3,7 +3,7 @@
 //   For website terms of use, trademark policy, privacy policy and other
 //   project policies see https://lfprojects.org/policies
 // Copyright (c) 2020, Control Command Inc. All rights reserved.
-// Copyright (c) 2018-2021, Sylabs Inc. All rights reserved.
+// Copyright (c) 2018-2023, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the
 // LICENSE.md file distributed with the sources of this project regarding your
 // rights to use or distribute this software.
@@ -14,6 +14,7 @@ import (
 	"errors"
 	"fmt"
 	"os"
+	"runtime"
 	"syscall"
 
 	"github.com/apptainer/apptainer/docs"
@@ -22,7 +23,7 @@ import (
 	"github.com/apptainer/apptainer/pkg/cmdline"
 	"github.com/apptainer/apptainer/pkg/image"
 	"github.com/apptainer/apptainer/pkg/sylog"
-	ocitypes "github.com/containers/image/v5/types"
+	"github.com/google/go-containerregistry/pkg/authn"
 	"github.com/spf13/cobra"
 	"golang.org/x/term"
 )
@@ -31,9 +32,12 @@ var buildArgs struct {
 	sections            []string
 	bindPaths           []string
 	mounts              []string
+	buildArch           string
+	buildArchVariant    string
 	libraryURL          string
 	keyServerURL        string
 	webURL              string
+	mksquashfsArgs      string
 	encrypt             bool
 	fakeroot            bool
 	fakefakeroot        bool
@@ -110,6 +114,26 @@ var buildNoTestFlag = cmdline.Flag{
 	EnvKeys:      []string{"NOTEST"},
 }
 
+// --arch
+var buildArchFlag = cmdline.Flag{
+	ID:           "buildArchFlag",
+	Value:        &buildArgs.buildArch,
+	DefaultValue: runtime.GOARCH,
+	Name:         "arch",
+	Usage:        "architecture to build for",
+	EnvKeys:      []string{"BUILD_ARCH"},
+}
+
+// --arch-variant
+var buildArchVariantFlag = cmdline.Flag{
+	ID:           "buildArchVariantFlag",
+	Value:        &buildArgs.buildArchVariant,
+	DefaultValue: "",
+	Name:         "arch-variant",
+	Usage:        "architecture variant to build for",
+	EnvKeys:      []string{"BUILD_ARCH_VARIANT"},
+}
+
 // --library
 var buildLibraryFlag = cmdline.Flag{
 	ID:           "buildLibraryFlag",
@@ -172,6 +196,16 @@ var buildFixPermsFlag = cmdline.Flag{
 	EnvKeys:      []string{"FIXPERMS"},
 }
 
+// --mksquashfs-args
+var buildMksquashfsArgsFlag = cmdline.Flag{
+	ID:           "mksquashfsArgsFlag",
+	Value:        &buildArgs.mksquashfsArgs,
+	DefaultValue: "",
+	Name:         "mksquashfs-args",
+	Usage:        "extra arguments to pass to mksquashfs when creating SIF files",
+	EnvKeys:      []string{"MKSQUASHFS_ARGS"},
+}
+
 // --nv
 var buildNvFlag = cmdline.Flag{
 	ID:           "nvFlag",
@@ -324,7 +358,10 @@ func init() {
 		cmdManager.RegisterFlagForCmd(&buildEncryptFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildFakerootFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildFixPermsFlag, buildCmd)
+		cmdManager.RegisterFlagForCmd(&buildMksquashfsArgsFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildJSONFlag, buildCmd)
+		cmdManager.RegisterFlagForCmd(&buildArchFlag, buildCmd)
+		cmdManager.RegisterFlagForCmd(&buildArchVariantFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildLibraryFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildNoCleanupFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildNoTestFlag, buildCmd)
@@ -359,6 +396,7 @@ func init() {
 		cmdManager.RegisterFlagForCmd(&buildVarArgsFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildVarArgFileFlag, buildCmd)
 		cmdManager.RegisterFlagForCmd(&buildArgUnusedWarn, buildCmd)
+		cmdManager.RegisterFlagForCmd(&commonAuthFileFlag, buildCmd)
 	})
 }
 
@@ -377,6 +415,10 @@ var buildCmd = &cobra.Command{
 }
 
 func preRun(cmd *cobra.Command, args []string) {
+	if promptForPassphrase || cmd.Flags().Lookup("pem-path").Changed {
+		// these imply --encrypt
+		buildArgs.encrypt = true
+	}
 	spec := args[len(args)-1]
 	isDeffile := fs.IsFile(spec) && !isImage(spec)
 	if buildArgs.fakeroot {
@@ -468,34 +510,37 @@ func checkBuildTarget(path string) error {
 	return nil
 }
 
-// makeDockerCredentials creates an *ocitypes.DockerAuthConfig to use for
-// OCI/Docker registry operation configuration. Note that if we don't have a
-// username or password set it will return a nil pointer, as containers/image
-// requires this to fall back to .docker/config based authentication.
-func makeDockerCredentials(cmd *cobra.Command) (authConf *ocitypes.DockerAuthConfig, err error) {
+// makeOCICredentials creates an *authn.AuthConfig that should be used for
+// explicit OCI/Docker registry authentication when appropriate. If
+// `--docker-login` has been specified then interactive authentication will be
+// performed. If `--docker-login` has not been specified, and explicit
+// credentials have not been supplied via env-vars/flags, then a nil AuthConfig
+// will be returned.
+func makeOCICredentials(cmd *cobra.Command) (*authn.AuthConfig, error) {
 	usernameFlag := cmd.Flags().Lookup("docker-username")
 	passwordFlag := cmd.Flags().Lookup("docker-password")
 
+	var err error
 	if dockerLogin {
 		if !usernameFlag.Changed {
-			dockerAuthConfig.Username, err = interactive.AskQuestion("Enter Docker Username: ")
+			authConfig.Username, err = interactive.AskQuestion("Enter Docker Username: ")
 			if err != nil {
-				return authConf, err
+				return &authConfig, nil
 			}
-			usernameFlag.Value.Set(dockerAuthConfig.Username)
+			usernameFlag.Value.Set(authConfig.Username)
 			usernameFlag.Changed = true
 		}
 
-		dockerAuthConfig.Password, err = interactive.AskQuestionNoEcho("Enter Docker Password: ")
+		authConfig.Password, err = interactive.AskQuestionNoEcho("Enter Docker Password: ")
 		if err != nil {
-			return authConf, err
+			return &authConfig, nil
 		}
-		passwordFlag.Value.Set(dockerAuthConfig.Password)
+		passwordFlag.Value.Set(authConfig.Password)
 		passwordFlag.Changed = true
 	}
 
 	if usernameFlag.Changed || passwordFlag.Changed {
-		return &dockerAuthConfig, nil
+		return &authConfig, nil
 	}
 
 	// If a username / password have not been explicitly set, return a nil
