@@ -3,7 +3,7 @@
 //   For website terms of use, trademark policy, privacy policy and other
 //   project policies see https://lfprojects.org/policies
 // Copyright (c) 2020, Control Command Inc. All rights reserved.
-// Copyright (c) 2018-2021, Sylabs Inc. All rights reserved.
+// Copyright (c) 2018-2023, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the
 // LICENSE.md file distributed with the sources of this project regarding your
 // rights to use or distribute this software.
@@ -22,9 +22,11 @@ import (
 
 	"github.com/apptainer/apptainer/internal/pkg/build"
 	"github.com/apptainer/apptainer/internal/pkg/build/args"
+	"github.com/apptainer/apptainer/internal/pkg/build/oci"
 	"github.com/apptainer/apptainer/internal/pkg/buildcfg"
 	"github.com/apptainer/apptainer/internal/pkg/cache"
 	"github.com/apptainer/apptainer/internal/pkg/fakeroot"
+	"github.com/apptainer/apptainer/internal/pkg/ociplatform"
 	"github.com/apptainer/apptainer/internal/pkg/remote/endpoint"
 	fakerootConfig "github.com/apptainer/apptainer/internal/pkg/runtime/engine/fakeroot/config"
 	"github.com/apptainer/apptainer/internal/pkg/util/env"
@@ -219,6 +221,10 @@ func runBuild(cmd *cobra.Command, args []string) {
 		os.Setenv("APPTAINER_WRITABLE_TMPFS", "1")
 	}
 
+	if cmd.Flags().Lookup("authfile").Changed && buildArgs.remote {
+		sylog.Fatalf("Custom authfile is not supported for remote build")
+	}
+
 	// check if target collides with existing file
 	if err := checkBuildTarget(dest); err != nil {
 		sylog.Fatalf("While checking build target: %s", err)
@@ -231,7 +237,7 @@ func runBuild(cmd *cobra.Command, args []string) {
 func runBuildLocal(ctx context.Context, cmd *cobra.Command, dst, spec string, fakerootPath string) {
 	var keyInfo *cryptkey.KeyInfo
 	unprivilege := false
-	if buildArgs.encrypt || promptForPassphrase || cmd.Flags().Lookup("pem-path").Changed {
+	if buildArgs.encrypt {
 		if namespaces.IsUnprivileged() {
 			unprivilege = true
 		}
@@ -265,7 +271,7 @@ func runBuildLocal(ctx context.Context, cmd *cobra.Command, dst, spec string, fa
 		sylog.Fatalf("Could not check build sections: %v", err)
 	}
 
-	authConf, err := makeDockerCredentials(cmd)
+	authConf, err := makeOCICredentials(cmd)
 	if err != nil {
 		sylog.Fatalf("While creating Docker credentials: %v", err)
 	}
@@ -346,6 +352,16 @@ func runBuildLocal(ctx context.Context, cmd *cobra.Command, dst, spec string, fa
 
 	}
 
+	arch, err := oci.ConvertArch(buildArgs.buildArch, buildArgs.buildArchVariant)
+	if err != nil {
+		sylog.Fatalf("While processing the arch and arch variant: %v", err)
+		return
+	}
+	dp, err := ociplatform.DefaultPlatform()
+	if err != nil {
+		sylog.Fatalf("%v", err)
+	}
+
 	b, err := build.New(
 		defs,
 		build.Config{
@@ -365,13 +381,17 @@ func runBuildLocal(ctx context.Context, cmd *cobra.Command, dst, spec string, fa
 				LibraryAuthToken:  authToken,
 				FakerootPath:      fakerootPath,
 				KeyServerOpts:     ko,
-				DockerAuthConfig:  authConf,
+				OCIAuthConfig:     authConf,
 				DockerDaemonHost:  dockerHost,
 				EncryptionKeyInfo: keyInfo,
 				FixPerms:          buildArgs.fixPerms,
 				SandboxTarget:     sandboxTarget,
+				MksquashfsArgs:    buildArgs.mksquashfsArgs,
 				Binds:             buildArgs.bindPaths,
 				Unprivilege:       unprivilege,
+				ReqAuthFile:       reqAuthFile,
+				Arch:              arch,
+				Platform:          *dp,
 			},
 		})
 	if err != nil {
