@@ -11,7 +11,6 @@
 package remote
 
 import (
-	"errors"
 	"fmt"
 	"log"
 	"os"
@@ -20,6 +19,7 @@ import (
 
 	"github.com/apptainer/apptainer/e2e/internal/e2e"
 	"github.com/apptainer/apptainer/e2e/internal/testhelper"
+	"github.com/apptainer/apptainer/internal/pkg/util/fs"
 	"github.com/apptainer/apptainer/pkg/syfs"
 )
 
@@ -571,6 +571,40 @@ func (c ctx) remoteUseExclusive(t *testing.T) {
 		testRemote    = "e2e"
 	)
 
+	// Move the user's and root's remote.yaml files aside for the purposes of this test
+	origRelPath := filepath.Join(".apptainer", "remote.yaml")
+	asideRelPath := fmt.Sprintf("%s.aside-remoteUseExclusive", origRelPath)
+	moveAsideRemoteYAML := func(t *testing.T) {
+		homeDir := e2e.CurrentUser(t).Dir
+		origRemoteYAML := filepath.Join(homeDir, origRelPath)
+		asideRemoteYAML := filepath.Join(homeDir, asideRelPath)
+		if !fs.IsReadable(origRemoteYAML) {
+			return
+		}
+		if err := os.Rename(origRemoteYAML, asideRemoteYAML); err != nil {
+			t.Fatalf("While trying to mv %q to %q: %v", origRemoteYAML, asideRemoteYAML, err)
+		}
+	}
+	restoreRemoteYAML := func(t *testing.T) {
+		homeDir := e2e.CurrentUser(t).Dir
+		origRemoteYAML := filepath.Join(homeDir, origRelPath)
+		asideRemoteYAML := filepath.Join(homeDir, asideRelPath)
+		if !fs.IsReadable(asideRemoteYAML) {
+			return
+		}
+		if err := os.Rename(asideRemoteYAML, origRemoteYAML); err != nil {
+			t.Fatalf("While trying to mv %q to %q: %v", asideRemoteYAML, origRemoteYAML, err)
+		}
+	}
+
+	moveAsideRemoteYAML(t)
+	e2e.Privileged(moveAsideRemoteYAML)(t)
+
+	t.Cleanup(func() {
+		restoreRemoteYAML(t)
+		e2e.Privileged(restoreRemoteYAML)(t)
+	})
+
 	tests := []struct {
 		name       string
 		command    string
@@ -703,65 +737,28 @@ func (c ctx) testDockerFallbackConfig(t *testing.T) {
 		}
 	})
 
-	var (
-		registry = fmt.Sprintf("oras://%s", c.env.TestRegistry)
-		repo     = fmt.Sprintf("oras://%s/private/e2e:1.0.0", c.env.TestRegistry)
-	)
-
-	c.env.RunApptainer(
-		t,
-		e2e.AsSubtest(`remote login`),
-		e2e.WithProfile(e2e.UserProfile),
-		e2e.WithCommand("remote login"),
-		e2e.WithArgs([]string{"-u", e2e.DefaultUsername, "-p", e2e.DefaultPassword, registry}...),
-		e2e.ExpectExit(0),
-	)
-
-	c.env.RunApptainer(
-		t,
-		e2e.AsSubtest(`push image`),
-		e2e.WithProfile(e2e.UserProfile),
-		e2e.WithCommand("push"),
-		e2e.WithArgs([]string{c.env.ImagePath, repo}...),
-		e2e.ExpectExit(0),
-	)
+	prevCwd, err := os.Getwd()
+	if err != nil {
+		t.Fatalf("could not get current working directory: %s", err)
+	}
+	defer os.Chdir(prevCwd)
+	if err = os.Chdir(tmpdir); err != nil {
+		t.Fatalf("could not change cwd to %q: %s", tmpdir, err)
+	}
 
 	user := e2e.CurrentUser(t)
 	defaultConfig := filepath.Join(user.Dir, ".apptainer", syfs.DockerConfFile)
 	dockerPath := filepath.Join(user.Dir, ".docker")
 	dockerConfig := filepath.Join(dockerPath, "config.json")
 
+	e2e.PrivateRepoLogin(t, c.env, e2e.UserProfile, "")
+
 	c.env.RunApptainer(
 		t,
 		e2e.AsSubtest(`try pulling oras image`),
 		e2e.WithProfile(e2e.UserProfile),
 		e2e.WithCommand("pull"),
-		e2e.WithArgs([]string{"--disable-cache", "--force", filepath.Join(tmpdir, "image.sif"), repo}...),
-		e2e.ExpectExit(0),
-		e2e.PostRun(func(t *testing.T) {
-			// move the ~/.apptainer/docker-config.json to ~/.docker/config.json
-			if _, err := os.Stat(defaultConfig); err != nil && errors.Is(err, os.ErrNotExist) {
-				t.Fatalf("Failed to find the default config: %s", defaultConfig)
-			}
-
-			err := os.MkdirAll(dockerPath, 0o755)
-			if err != nil {
-				t.Fatalf("Failed to create docker config path: %s", dockerPath)
-			}
-
-			err = os.Rename(defaultConfig, dockerConfig)
-			if err != nil {
-				t.Fatalf("Failed to move default apptainer config: %s to docker config path: %s", defaultConfig, dockerConfig)
-			}
-		}),
-	)
-
-	c.env.RunApptainer(
-		t,
-		e2e.AsSubtest(`try pulling oras image again`),
-		e2e.WithProfile(e2e.UserProfile),
-		e2e.WithCommand("pull"),
-		e2e.WithArgs([]string{"--disable-cache", "--force", filepath.Join(tmpdir, "image.sif"), repo}...),
+		e2e.WithArgs([]string{"--disable-cache", "--force", "--no-https", filepath.Join(tmpdir, "image.sif"), c.env.TestRegistryPrivImage}...),
 		e2e.ExpectExit(0),
 		e2e.PostRun(func(t *testing.T) {
 			// move back
@@ -774,12 +771,14 @@ func (c ctx) testDockerFallbackConfig(t *testing.T) {
 
 	c.env.RunApptainer(
 		t,
-		e2e.AsSubtest(`logout`),
+		e2e.AsSubtest(`try pulling oras image again`),
 		e2e.WithProfile(e2e.UserProfile),
-		e2e.WithCommand("remote logout"),
-		e2e.WithArgs([]string{registry}...),
+		e2e.WithCommand("pull"),
+		e2e.WithArgs([]string{"--disable-cache", "--force", "--no-https", filepath.Join(tmpdir, "image.sif"), c.env.TestRegistryPrivImage}...),
 		e2e.ExpectExit(0),
 	)
+
+	e2e.PrivateRepoLogout(t, c.env, e2e.UserProfile, "")
 }
 
 // E2ETests is the main func to trigger the test suite
