@@ -3,7 +3,7 @@
 //   For website terms of use, trademark policy, privacy policy and other
 //   project policies see https://lfprojects.org/policies
 // Copyright (c) 2020, Control Command Inc. All rights reserved.
-// Copyright (c) 2018-2023, Sylabs Inc. All rights reserved.
+// Copyright (c) 2018-2025, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the
 // LICENSE.md file distributed with the sources of this project regarding your
 // rights to use or distribute this software.
@@ -25,10 +25,9 @@ import (
 	"github.com/ProtonMail/go-crypto/openpgp"
 	"github.com/apptainer/apptainer/internal/pkg/buildcfg"
 	"github.com/apptainer/apptainer/internal/pkg/cgroups"
-	fakerootutil "github.com/apptainer/apptainer/internal/pkg/fakeroot"
+	"github.com/apptainer/apptainer/internal/pkg/fakeroot"
 	"github.com/apptainer/apptainer/internal/pkg/image/driver"
 	"github.com/apptainer/apptainer/internal/pkg/instance"
-	"github.com/apptainer/apptainer/internal/pkg/plugin"
 	"github.com/apptainer/apptainer/internal/pkg/runtime/engine/config/starter"
 	"github.com/apptainer/apptainer/internal/pkg/security"
 	"github.com/apptainer/apptainer/internal/pkg/security/seccomp"
@@ -41,13 +40,13 @@ import (
 	"github.com/apptainer/apptainer/internal/pkg/util/mainthread"
 	"github.com/apptainer/apptainer/internal/pkg/util/user"
 	"github.com/apptainer/apptainer/pkg/image"
-	fakerootcallback "github.com/apptainer/apptainer/pkg/plugin/callback/runtime/fakeroot"
 	apptainerConfig "github.com/apptainer/apptainer/pkg/runtime/engine/apptainer/config"
 	"github.com/apptainer/apptainer/pkg/runtime/engine/config"
 	"github.com/apptainer/apptainer/pkg/sylog"
 	"github.com/apptainer/apptainer/pkg/util/capabilities"
 	"github.com/apptainer/apptainer/pkg/util/fs/proc"
 	"github.com/apptainer/apptainer/pkg/util/namespaces"
+	"github.com/apptainer/apptainer/pkg/util/slice"
 	"github.com/opencontainers/runtime-spec/specs-go"
 	"golang.org/x/sys/unix"
 )
@@ -100,7 +99,7 @@ func (e *EngineOperations) PrepareConfig(starterConfig *starter.Config) error {
 		if fakerootPath := e.EngineConfig.GetFakerootPath(); fakerootPath != "" {
 			// look for fakeroot again because the PATH used is
 			//  more restricted at this point than it was earlier
-			newPath, err := fakerootutil.FindFake()
+			newPath, err := fakeroot.FindFake()
 			if err != nil {
 				return fmt.Errorf("error finding fakeroot in privileged PATH: %v", err)
 			}
@@ -536,22 +535,111 @@ func (e *EngineOperations) prepareAutofs(starterConfig *starter.Config) error {
 	return nil
 }
 
+// removeNamespace is used to remove a namespace from the slice of namespaces.
+// It is used mainly within prepareContainerConfig(...)
+func (e *EngineOperations) removeNamespace(namespaceType specs.LinuxNamespaceType) {
+	if e.EngineConfig.OciConfig.Linux == nil {
+		return
+	}
+
+	namespaces := e.EngineConfig.OciConfig.Linux.Namespaces
+	for i, ns := range namespaces {
+		if ns.Type == namespaceType {
+			sylog.Warningf("Not virtualizing %s namespace by configuration", namespaceType)
+			e.EngineConfig.OciConfig.Linux.Namespaces = append(namespaces[:i], namespaces[i+1:]...)
+			break
+		}
+	}
+}
+
+// hasNamespaces checks for existence of a specific namespace in the namespaces slice.
+func (e *EngineOperations) hasNamespace(namespaceType specs.LinuxNamespaceType) (bool, string) {
+	namespaces := e.EngineConfig.OciConfig.Linux.Namespaces
+	for _, ns := range namespaces {
+		if namespaceType == ns.Type {
+			return true, ns.Path
+		}
+	}
+	return false, ""
+}
+
+func (e *EngineOperations) joinNetns(starterConfig *starter.Config) error {
+	// No netns path requested - nothing to validate here.
+	ok, netnsPath := e.hasNamespace(specs.NetworkNamespace)
+	if !ok || netnsPath == "" {
+		return nil
+	}
+
+	// The netns path must already exist.
+	_, err := os.Stat(netnsPath)
+	if err != nil {
+		return fmt.Errorf("while checking netns path: %w", err)
+	}
+
+	// Root can join any network namespace.
+	euid := os.Geteuid()
+	if euid == 0 {
+		return starterConfig.SetNsPath(specs.NetworkNamespace, netnsPath)
+	}
+
+	// Is the user permitted in the list of unpriv users / groups permitted to join netns?
+	allowedNetUser, err := user.UIDInList(euid, e.EngineConfig.File.AllowNetUsers)
+	if err != nil {
+		return err
+	}
+	allowedNetGroup, err := user.UIDInAnyGroup(euid, e.EngineConfig.File.AllowNetGroups)
+	if err != nil {
+		return err
+	}
+	// Is the netns path permitted in apptainer conf?
+	permittedPath := slice.ContainsString(e.EngineConfig.File.AllowNetnsPaths, netnsPath)
+
+	if !permittedPath {
+		return fmt.Errorf("%q is not an allowed netns path in singularity.conf", netnsPath)
+	}
+
+	if !(allowedNetUser || allowedNetGroup) {
+		return fmt.Errorf("you are not permitted to join network namespaces in apptainer.conf")
+	}
+
+	return starterConfig.SetNsPath(specs.NetworkNamespace, netnsPath)
+}
+
 // prepareContainerConfig is responsible for getting and applying
 // user supplied configuration for container creation.
 func (e *EngineOperations) prepareContainerConfig(starterConfig *starter.Config) error {
 	// always set mount namespace
 	e.EngineConfig.OciConfig.AddOrReplaceLinuxNamespace(specs.MountNamespace, "")
 
-	// if PID namespace is not allowed remove it from namespaces
-	if !e.EngineConfig.File.AllowPidNs && e.EngineConfig.OciConfig.Linux != nil {
-		namespaces := e.EngineConfig.OciConfig.Linux.Namespaces
-		for i, ns := range namespaces {
-			if ns.Type == specs.PIDNamespace {
-				sylog.Debugf("Not virtualizing PID namespace by configuration")
-				e.EngineConfig.OciConfig.Linux.Namespaces = append(namespaces[:i], namespaces[i+1:]...)
-				break
-			}
+	// If any namespace is not allowed remove it from namespaces
+	if !e.EngineConfig.File.AllowIpcNs {
+		e.removeNamespace(specs.IPCNamespace)
+	}
+
+	if !e.EngineConfig.File.AllowPidNs {
+		e.removeNamespace(specs.PIDNamespace)
+	}
+
+	if !e.EngineConfig.File.AllowUserNs {
+		if buildcfg.APPTAINER_SUID_INSTALL == 0 {
+			sylog.Fatalf("Unprivileged installation found, user namepace needed but not allowed by configuration.")
 		}
+		if n, _ := e.hasNamespace(specs.UserNamespace); n {
+			sylog.Fatalf("User namespace required but not allowed by configuration.")
+		}
+	}
+
+	if !e.EngineConfig.File.AllowUtsNs {
+		e.removeNamespace(specs.UTSNamespace)
+		if e.EngineConfig.OciConfig.Hostname != "" {
+			sylog.Warningf("Container hostname cannot be set.")
+		}
+	}
+
+	// Validate and apply any request to join an existing network namespace.
+	// Must be root or authorized in singularity.conf.
+	if err := e.joinNetns(starterConfig); err != nil {
+		return err
 	}
 
 	if os.Getuid() == 0 {
@@ -575,7 +663,7 @@ func (e *EngineOperations) prepareContainerConfig(starterConfig *starter.Config)
 		uid := uint32(os.Getuid())
 		gid := uint32(os.Getgid())
 
-		if !starterConfig.GetIsSUID() && fakerootutil.IsUIDMapped(uid) {
+		if !starterConfig.GetIsSUID() && fakeroot.IsUIDMapped(uid) {
 			// no SUID workflow, check if newuidmap/newgidmap are present
 			sylog.Verbosef("Fakeroot requested with unprivileged workflow, fallback to newuidmap/newgidmap")
 			sylog.Debugf("Search for newuidmap binary")
@@ -588,21 +676,8 @@ func (e *EngineOperations) prepareContainerConfig(starterConfig *starter.Config)
 			}
 		}
 
-		getIDRange := fakerootutil.GetIDRange
-
-		callbackType := (fakerootcallback.UserMapping)(nil)
-		callbacks, err := plugin.LoadCallbacks(callbackType)
-		if err != nil {
-			return fmt.Errorf("while loading plugins callbacks '%T': %s", callbackType, err)
-		}
-		if len(callbacks) > 1 {
-			return fmt.Errorf("multiple plugins have registered hook callback for fakeroot")
-		} else if len(callbacks) == 1 {
-			getIDRange = callbacks[0].(fakerootcallback.UserMapping)
-		}
-
 		e.EngineConfig.OciConfig.AddLinuxUIDMapping(uid, 0, 1)
-		idRange, err := getIDRange(fakerootutil.SubUIDFile, uid)
+		idRange, err := fakeroot.GetUIDRange(uid)
 		if err != nil {
 			return fmt.Errorf("could not use fakeroot: %s", err)
 		}
@@ -610,7 +685,7 @@ func (e *EngineOperations) prepareContainerConfig(starterConfig *starter.Config)
 		starterConfig.AddUIDMappings(e.EngineConfig.OciConfig.Linux.UIDMappings)
 
 		e.EngineConfig.OciConfig.AddLinuxGIDMapping(gid, 0, 1)
-		idRange, err = getIDRange(fakerootutil.SubGIDFile, uid)
+		idRange, err = fakeroot.GetGIDRange(uid)
 		if err != nil {
 			return fmt.Errorf("could not use fakeroot: %s", err)
 		}
