@@ -21,7 +21,6 @@ import (
 	"os/exec"
 	"os/signal"
 	"path/filepath"
-	"reflect"
 	"regexp"
 	"runtime"
 	"strconv"
@@ -92,9 +91,11 @@ func (e *EngineOperations) StartProcess(masterConnFd int) error {
 		if customCwd {
 			return fmt.Errorf("failed to set working directory: %s", err)
 		}
-		if err := os.Chdir(e.EngineConfig.GetHomeDest()); err != nil {
-			sylog.Debugf("Error setting the working directory. Using '/' instead: %s", err)
+		if cerr := os.Chdir(e.EngineConfig.GetHomeDest()); cerr != nil {
+			sylog.Warningf("Error changing the container working directory. Using '/' instead: %s", cerr)
 			os.Chdir("/")
+		} else {
+			sylog.Warningf("Error changing the container working directory. Using '%s' instead: %s", e.EngineConfig.GetHomeDest(), err)
 		}
 	}
 
@@ -238,17 +239,19 @@ func (e *EngineOperations) StartProcess(masterConnFd int) error {
 	// Modify argv argument and program name shown in /proc/self/comm
 	name := "appinit"
 
-	argv0str := (*reflect.StringHeader)(unsafe.Pointer(&os.Args[0]))
-	argv0 := (*[1 << 30]byte)(unsafe.Pointer(argv0str.Data))[:argv0str.Len]
-	progname := make([]byte, argv0str.Len)
+	argv0 := unsafe.Slice(unsafe.StringData(os.Args[0]), len(os.Args[0]))
+	progname := make([]byte, len(os.Args[0]))
 
-	if len(name) > argv0str.Len {
+	if len(name) > len(progname) {
 		return fmt.Errorf("program name too short")
 	}
 
 	copy(progname, name)
+
+	// Set name by overwriting argv[0]
 	copy(argv0, progname)
 
+	// Set name by PR_SET_NAME (only affects PR_GET_NAME)
 	ptr := unsafe.Pointer(&progname[0])
 	if _, _, err := syscall.Syscall(syscall.SYS_PRCTL, syscall.PR_SET_NAME, uintptr(ptr), 0); err != 0 {
 		return syscall.Errno(err)
@@ -340,7 +343,7 @@ func (e *EngineOperations) StartProcess(masterConnFd int) error {
 // and thus no additional privileges can be gained.
 //
 // Here, however, apptainer engine does not escalate privileges.
-func (e *EngineOperations) PostStartProcess(ctx context.Context, pid int) error {
+func (e *EngineOperations) PostStartProcess(_ context.Context, pid int) error {
 	sylog.Debugf("Post start process")
 
 	callbackType := (apptainercallback.PostStartProcess)(nil)
@@ -437,7 +440,6 @@ func (e *EngineOperations) PostStartProcess(ctx context.Context, pid int) error
 		}
 
 		err = file.Update()
-
 		if err != nil {
 			return err
 		}
@@ -717,10 +719,10 @@ func injectEnvHandler(senv map[string]string, noEval bool) interpreter.OpenHandl
 	}
 }
 
-func runtimeVarsHandler(senv map[string]string) interpreter.OpenHandler {
+func runtimeVarsHandler() interpreter.OpenHandler {
 	var once sync.Once
 
-	return func(path string, _ int, _ os.FileMode) (io.ReadWriteCloser, error) {
+	return func(_ string, _ int, _ os.FileMode) (io.ReadWriteCloser, error) {
 		b := new(bufferCloser)
 
 		once.Do(func() {
@@ -732,7 +734,7 @@ func runtimeVarsHandler(senv map[string]string) interpreter.OpenHandler {
 }
 
 // sylogBuiltin allows to use sylog logger from shell script.
-func sylogBuiltin(ctx context.Context, argv []string) error {
+func sylogBuiltin(_ context.Context, argv []string) error {
 	if len(argv) < 2 {
 		return fmt.Errorf("sylog builtin requires two arguments")
 	}
@@ -752,8 +754,8 @@ func sylogBuiltin(ctx context.Context, argv []string) error {
 }
 
 // getAllEnvBuiltin display all exported variables in the form KEY=VALUE.
-func getAllEnvBuiltin(shell *interpreter.Shell) interpreter.ShellBuiltin {
-	return func(ctx context.Context, argv []string) error {
+func getAllEnvBuiltin() interpreter.ShellBuiltin {
+	return func(ctx context.Context, _ []string) error {
 		hc := interp.HandlerCtx(ctx)
 
 		keyRe := regexp.MustCompile(`^[a-zA-Z_]+[a-zA-Z0-9_]*$`)
@@ -786,7 +788,7 @@ func getAllEnvBuiltin(shell *interpreter.Shell) interpreter.ShellBuiltin {
 
 // fixPathBuiltin takes the current path value to fix it by injecting
 // missing default path and returns value on shell interpreter output.
-func fixPathBuiltin(ctx context.Context, argv []string) error {
+func fixPathBuiltin(ctx context.Context, _ []string) error {
 	hc := interp.HandlerCtx(ctx)
 
 	currentPath := filepath.SplitList(hc.Env.Get("PATH").String())
@@ -812,7 +814,7 @@ func fixPathBuiltin(ctx context.Context, argv []string) error {
 
 // hashBuiltin is a noop function for hash bash builtin, since we don't
 // store resolved path in a hash table, there is nothing to do.
-func hashBuiltin(ctx context.Context, argv []string) error {
+func hashBuiltin(_ context.Context, _ []string) error {
 	return nil
 }
 
@@ -892,10 +894,10 @@ func runActionScript(engineConfig *apptainerConfig.EngineConfig) ([]string, []st
 	senv := engineConfig.GetApptainerEnv()
 	shell.RegisterOpenHandler("/.inject-apptainer-env.sh", injectEnvHandler(senv, engineConfig.GetNoEval()))
 
-	shell.RegisterOpenHandler("/.singularity.d/env/99-runtimevars.sh", runtimeVarsHandler(senv))
+	shell.RegisterOpenHandler("/.singularity.d/env/99-runtimevars.sh", runtimeVarsHandler())
 
 	// register few builtin
-	shell.RegisterShellBuiltin("getallenv", getAllEnvBuiltin(shell))
+	shell.RegisterShellBuiltin("getallenv", getAllEnvBuiltin())
 	shell.RegisterShellBuiltin("sylog", sylogBuiltin)
 	shell.RegisterShellBuiltin("fixpath", fixPathBuiltin)
 	shell.RegisterShellBuiltin("hash", hashBuiltin)
